# GetPaymentMethodSnapshotResponsePaymentMethodStatus

Specifies the status of the payment method.

## Enum

* `ACTIVE` (value: `'Active'`)

* `CLOSED` (value: `'Closed'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


